pytest-workaround-12888
=======================

adds an `import readline` `.pth` file to trigger early import of readline

this works around [issue 12888]

[issue 12888]: https://github.com/pytest-dev/pytest/issues/12888

## installation

```bash
pip install pytest-workaround-12888
```
